@@ -10,10 +10,7 @@ OC.L10N.register(
     "Download" : "Yüklə",
     "can edit" : "dəyişmək olar",
     "Add" : "Əlavə etmək",
-    "Password protection" : "Password protection",
     "Save" : "Saxla",
-    "Description" : "Açıqlanma",
-    "Settings" : "Settings",
     "Cancel" : "Dayandır",
     "Invalid image" : "Yalnış şəkil",
     "Name" : "Ad",
