@@ -48,6 +48,7 @@ OC.L10N.register(
     "New team name" : "Назва новай каманды",
     "Remove member" : "Выдаліць удзельніка",
     "Add to {circle}" : "Дадаць у {circle}",
+    "Pending" : "У чаканні",
     "Add contact in group" : "Дадаць кантакт у групу",
     "Member" : "Удзельнік",
     "Add member" : "Дадаць удзельніка",
@@ -56,11 +57,14 @@ OC.L10N.register(
     "Group" : "Група",
     "Email" : "Электронная пошта",
     "Owner" : "Уладальнік",
+    "Users" : "Карыстальнікі",
     "Additional names" : "Дадатковыя імёны",
     "Nickname" : "Псеўданім",
     "Notes" : "Нататкі",
     "Website" : "Вэб-сайт",
+    "Location" : "Месцазнаходжанне",
     "Home" : "Дадому",
+    "Address" : "Адрас",
     "Birthday" : "Дзень нараджэння",
     "Place of birth" : "Месца нараджэння",
     "Unknown" : "Невядомы"
