@@ -29,6 +29,7 @@ OC.L10N.register(
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
     "None" : "Ninguno",
+    "Member" : "Miembro",
     "New contact" : "Nuevo contacto",
     "Close" : "Cerrar",
     "Import" : "Importar",
@@ -37,7 +38,6 @@ OC.L10N.register(
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
-    "Member" : "Miembro",
     "Moderator" : "Moderador",
     "Admin" : "Administración",
     "Owner" : "Dueño",
@@ -89,9 +89,6 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido",
-    "Password protection" : "Protección con contraseña",
-    "Description" : "Descripción",
-    "Settings" : "Settings"
+    "Unknown" : "Desconocido"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
