@@ -19,10 +19,7 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
-    "Settings" : "Settings",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
     "Address book" : "Libreta de direcciones",
@@ -32,6 +29,7 @@ OC.L10N.register(
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
     "None" : "Ninguno",
+    "Member" : "Miembro",
     "New contact" : "Nuevo contacto",
     "Close" : "Cerrar",
     "Import" : "Importar",
@@ -40,10 +38,10 @@ OC.L10N.register(
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
-    "Member" : "Miembro",
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
+    "Privacy" : "Privacidad",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
