@@ -18,10 +18,7 @@ OC.L10N.register(
     "Last name" : "Nama belakang",
     "Display name" : "Nama tampilan",
     "Last modified" : "Terakhir diubah",
-    "Password protection" : "Password protection",
     "Save" : "Simpan",
-    "Description" : "Deskrisi",
-    "Settings" : "Settings",
     "Cancel" : "Membatalkan",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
@@ -39,6 +36,7 @@ OC.L10N.register(
     "Email" : "Email",
     "Admin" : "Admin",
     "Owner" : "Owner",
+    "Privacy" : "Privasi",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
     "Prefix" : "Prefix",
