@@ -13,10 +13,7 @@ OC.L10N.register(
     "Add" : "Derbäimaachen",
     "First name" : "Virnumm",
     "Last name" : "Famillje Numm",
-    "Password protection" : "Password protection",
     "Save" : "Späicheren",
-    "Description" : "Beschreiwung",
-    "Settings" : "Settings",
     "Cancel" : "Ofbriechen",
     "Invalid image" : "Ongülteg d'Bild",
     "Name" : "Numm",
