@@ -2,21 +2,18 @@ OC.L10N.register(
     "contacts",
     {
     "Details" : "معلومات",
-    "Download" : "ښکته کول",
-    "Groups" : "ګروپونه",
     "Rename" : "نوم بدلول",
     "Delete" : "ړنګول",
     "Copy link" : "لېنک کاپي کول",
+    "Download" : "ښکته کول",
     "Save" : "ساتل",
+    "Cancel" : "پرېښول",
     "Invalid image" : "انځور سم نه دی",
     "Name" : "نوم",
-    "Cancel" : "پرېښول",
     "Search contacts …" : "اړيکي پلټل ...",
     "Pending" : "د انتظار په حال کې",
     "Close" : "بندول",
-    "Circle" : "حلقه",
     "Admin" : "ستر کارن",
-    "Users" : "کارنان",
     "Notes" : "شسیب",
     "Home" : "کور",
     "Work" : "دفتر",
