@@ -19,10 +19,7 @@ OC.L10N.register(
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
-    "Password protection" : "Protecție parolă ",
     "Save" : "Salvează",
-    "Description" : "Descriere",
-    "Settings" : "Settings",
     "Cancel" : "Anulează",
     "Invalid image" : "Imagine invalidă",
     "Address book" : "Listă de contacte",
@@ -34,6 +31,7 @@ OC.L10N.register(
     "Pending" : "În așteptare",
     "None" : "Niciuna",
     "Select option" : "Selectatți opțiunea",
+    "Member" : "Membru",
     "New contact" : "Contact nou ",
     "Close" : "Închide",
     "Import" : "Importă",
@@ -43,11 +41,10 @@ OC.L10N.register(
     "Group" : "Grup",
     "Email" : "Email",
     "Contact" : "Contact",
-    "Member" : "Membru",
     "Moderator" : "Moderator",
     "Admin" : "Admin",
     "Owner" : "Proprietar",
-    "Visibility" : "Vizibil",
+    "Privacy" : "Confidențialitate",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
     "Prefix" : "Prefix",
