@@ -8,10 +8,7 @@ OC.L10N.register(
     "Download" : "Preuzmi",
     "can edit" : "može da menja",
     "Add" : "Dodaj",
-    "Password protection" : "Password protection",
     "Save" : "Sačuvaj",
-    "Description" : "Opis",
-    "Settings" : "Postavke",
     "Cancel" : "Otkaži",
     "Name" : "naziv",
     "Title" : "Naslov",
@@ -25,6 +22,7 @@ OC.L10N.register(
     "Email" : "email",
     "Moderator" : "Moderator",
     "Owner" : "Vlasnik",
+    "Privacy" : "Privatnost",
     "Notes" : "Notes",
     "Website" : "Sajt",
     "Home" : "Почетна",
